"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertInitialStateToStoreState = exports.convertToObj = exports.gitubInitialStoreSchema = exports.githubBlobSchema = exports.githubOrganizationSchema = exports.githubRepositorySchema = exports.githubUserSchema = void 0;
const zod_1 = require("zod");
const faker_1 = require("@faker-js/faker");
exports.githubUserSchema = zod_1.z
    .object({
    id: zod_1.z.string().or(zod_1.z.number()).default(""),
    login: zod_1.z.string(),
    name: zod_1.z.string().optional(),
    email: zod_1.z.string().optional(),
    organizations: zod_1.z.array(zod_1.z.string()),
})
    .transform((user) => {
    user.id = user.login;
    if (!user.name)
        user.name = user.login;
    if (!user.email)
        user.email = faker_1.faker.internet.email({ firstName: user.name });
    return user;
});
exports.githubRepositorySchema = zod_1.z
    .object({
    id: zod_1.z.string().or(zod_1.z.number()).default(""),
    name: zod_1.z.string(),
    owner: zod_1.z.string(),
    full_name: zod_1.z.string().optional().default(""),
    packages: zod_1.z.array(zod_1.z.string()).optional(),
})
    .transform((repo) => {
    repo.id = repo.name;
    repo.full_name = `${repo.owner}/${repo.name}`;
    return repo;
});
exports.githubOrganizationSchema = zod_1.z
    .object({
    id: zod_1.z.string().or(zod_1.z.number()).default(""),
    login: zod_1.z.string(),
    name: zod_1.z.string().optional(),
    email: zod_1.z.string().optional(),
    description: zod_1.z.string().optional(),
    created_at: zod_1.z
        .string()
        .default(() => faker_1.faker.date.recent().toISOString())
        .optional(),
    teams: zod_1.z.union([zod_1.z.array(zod_1.z.string()), zod_1.z.undefined()]),
})
    .transform((org) => {
    org.id = org.login;
    if (!(org === null || org === void 0 ? void 0 : org.name))
        org.name = org.login;
    if (!org.email)
        org.email = faker_1.faker.internet.email({
            firstName: "org",
            lastName: org.login,
        });
    return org;
});
exports.githubBlobSchema = zod_1.z
    .object({
    id: zod_1.z.string().or(zod_1.z.number()).default(""),
    content: zod_1.z.string().optional().default(faker_1.faker.lorem.paragraphs),
    encoding: zod_1.z
        .union([zod_1.z.literal("string"), zod_1.z.literal("base64")])
        .default("string"),
    owner: zod_1.z.string(),
    repo: zod_1.z.string(),
    // below we ensure that one of these is specified, but the other is then optional
    path: zod_1.z.string(),
    sha: zod_1.z.string(),
})
    .transform((blob, ctx) => {
    var _a, _b;
    if (!blob.path && !blob.sha) {
        ctx.addIssue({
            code: zod_1.z.ZodIssueCode.custom,
            message: "Specify the path or sha of the blob",
        });
        return zod_1.z.NEVER;
    }
    blob.id = `${blob.owner}/${blob.repo}/${(_b = (_a = blob === null || blob === void 0 ? void 0 : blob.path) !== null && _a !== void 0 ? _a : blob.sha) !== null && _b !== void 0 ? _b : "00000"}`;
    return blob;
});
exports.gitubInitialStoreSchema = zod_1.z.object({
    users: zod_1.z.array(exports.githubUserSchema),
    repositories: zod_1.z.array(exports.githubRepositorySchema),
    organizations: zod_1.z.array(exports.githubOrganizationSchema),
    blobs: zod_1.z.array(exports.githubBlobSchema),
});
const convertToObj = (arrayOfObjects) => arrayOfObjects.reduce((final, obj) => {
    final[obj.id] = obj;
    return final;
}, {});
exports.convertToObj = convertToObj;
const convertInitialStateToStoreState = (initialState) => {
    if (!initialState)
        return undefined;
    // TODO try to make this generic?
    const storeObject = {
        users: (0, exports.convertToObj)(initialState.users),
        repositories: (0, exports.convertToObj)(initialState.repositories),
        organizations: (0, exports.convertToObj)(initialState.organizations),
        blobs: (0, exports.convertToObj)(initialState.blobs),
    };
    return storeObject;
};
exports.convertInitialStateToStoreState = convertInitialStateToStoreState;
//# sourceMappingURL=entities.js.map